---
title: Thumbnail
description: Use thumbnails as a visual anchor and identifier for an object. They should be used along with text to provide context.
category: Images and icons
keywords:
  - photo
  - picture
  - image
  - small thumbnail
  - medium thumbnail
  - large thumbnail
  - image preview
examples:
  - fileName: thumbnail-default.tsx
    title: Default
    description: Use as the default size.
  - fileName: thumbnail-extra-small.tsx
    title: Extra small
    description: Use to present a thumbnail in a condensed layout, such as a data table cell or an action list item.
  - fileName: thumbnail-small.tsx
    title: Small
    description: Use when the default size is too large for the layout, or when the thumbnail has less importance.
  - fileName: thumbnail-large.tsx
    title: Large
    description: Use when a thumbnail is a major focal point. Avoid this size in lists of like items.
  - fileName: thumbnail-with-component-source.tsx
    title: With component source
    description: Use to render an icon inside of thumbnail.
---

## Best practices

On web, thumbnails should:

- Be one of 4 sizes:
  - Extra small (24 x 24 px): use in tightly condensed layouts
  - Small (40 × 40 px): use when the medium size is too large for the layout, or when the thumbnail has less importance.
  - Medium (60 × 60 px): use as the default size.
  - Large (80 × 80 px): use when an thumbnail is a major focal point. Avoid this size in lists of like items.

On Android and iOS, thumbnails should:

- Be one of 2 sizes:
  - Default (40 × 40): use as the default size.
  - Large (72 × 72): use when an thumbnail is a major focal point. Avoid this size in lists of like items.

---

## Content guidelines

Any time you use an image to communicate a concept on Shopify, it’s important to use descriptive [alt text](https://polaris.shopify.com/content/alternative-text). Doing this is important for [accessibility](https://polaris.shopify.com/foundations/internationalization) because it allows screen readers to describe what’s in the image to people who may not be able to see it.

For thumbnails, we recommend using a format that describes what will show in the image:

- On web, `alt="Photo of {product}"`. For example, “Photo of black t-shirt with cartoon tiger”.
- On web, an empty `alt=""` attribute ignores the image in assistive technologies such as screen readers, and may be used on decorative thumbnails.
- On iOS, `imageView.accessibilityLabel = "Photo of {product}"`. For example, “Photo of black t-shirt with cartoon tiger”.
- On Android, `android:contentDescription="Photo of {product}"`. For example, “Photo of black t-shirt with cartoon tiger”.

---

## Related components

- To present a thumbnail representation of an individual or business in the interface, [use the avatar component](https://polaris.shopify.com/components/avatar)
