---
title: Grammar and mechanics
description: This guide is to help designers, developers, recruiters, UX-ers, product managers, support advisors, or anyone who writes public-facing text for Shopify.
icon: GrammarMajor
keywords:
  - writing instructions
  - writing rules
  - writing guidelines
  - copy instructions
  - copy rules
  - copy guidelines
  - content instructions
  - content rules
  - content guidelines
  - writing public-facing text
  - public-facing text
  - writing public-facing copy
  - public-facing copy
  - writing public-facing content
  - public-facing content
---

## Basics

### Active voice

You should (almost) always write in the active voice:

- Subject (person/thing acting) verb (the action) object (receives the action)

Use the active voice if merchants need to do something. It should be clear that the subject is the one doing the action.

<!-- dodont -->

#### Do

Add details to the product

#### Don’t

Details were added to the product

<!-- end -->

### Passive voice

To tell if you’re using the passive voice, look out for:

- When the object comes before the subject (“the item was purchased by the customer”)
- Past tense verbs (“was added,” “was created,” and so on)
- Forms of the verb “to be” (“was,” “is,” “were,” and so on)

You should almost always write in the active voice, but here’s when to use the passive voice:

- To avoid referring to yourself or Shopify
- To make it clear that you didn’t personally take an action or make a decision
- If the object (thing being done) is more important than the subject (person doing the thing)

<!-- dodont -->

#### Do

Invoices are created monthly and emailed to
[marki.yeung@nomail.com](mailto:Marki.Yeung@nomail.com)

#### Don’t

Shopify creates and emails your invoices monthly to
[simran.robichaud@nomail.com](mailto:Simran.Robichaud@nomail.com)

<!-- end -->

### Contractions

Contractions are abbreviated words. We use them to set a light and casual tone in the interface. The goal is to sound human, so avoid contracting verbs that sound awkward when you say them out loud, or have been phased out of modern day speech.

<!-- dodont -->

#### Do

- You can’t have products with negative weights
- Your products don’t have weights
- You’re all set up
- This product doesn’t require shipping
- The customer name shouldn’t contain numbers
- It’s a good time to plan your Black Friday sale
- An error occurred and your changes couldn’t be saved
- I’m Kit, your digital marketing assistant
- This transfer hasn’t been received
- You haven’t connected your account
- You’ve exceeded 10 password attempts

#### Don’t

- That’ll make sure you are all set up
- It would’ve been possible if you’d installed the latest updates
- The set up was not complete, but this’ll do
- There’re 10 products in this collection
- Your product mustn’t be more than 20kgs
- This product needn’t be shipped
- There are 3 visitors who’ve viewed this product
- You gotta set up Shopify Payments to use Shopify Capital
- It’d be a good idea to place an ad this weekend

<!-- end -->

### Plain language

Use words and language that our merchants use. Avoid jargon or technical terminology. Make sure each sentence has a single focus and keep them short. Aim for a Grade 7 reading level.

<!-- dodont -->

#### Do

- We’ve made some changes to improve your store’s security
- These products aren’t getting a lot of views, but visitors are adding them to their carts

#### Don’t

- Your SSL certificates were activated
- These are your less popular products with the highest add-to-cart conversion

<!-- end -->

---

## Capitalization

### Headings

Use sentence case for all headings:

- Capitalize the first word of a heading
- Capitalize proper or trademarked nouns (names of products, countries, or people)
- Lowercase for everything else

<!-- dodont -->

#### Do

Create purchase order

#### Don’t

Create Purchase Order

<!-- end -->

### Product and feature names

In general, if a feature or product isn’t unique to Shopify, don’t capitalize it (such as blogs, navigation, pages). If it’s unique to Shopify and marketable as its own product, capitalize it (such as Shopify Payments, or Frenzy).

<!-- dodont -->

#### Do

- blogs
- navigation
- Shopify Payments

#### Don’t

- Blogs
- Navigation
- shopify payments

<!-- end -->

### Trademarks

Respect the usage guidelines of any third-party intellectual property. For example, in US communications, Apple Pay requires you to include the trademark symbol (™) the first time Apple Pay appears in body copy.

Review the third party’s brand usage guidelines to make sure you are using the company’s name and logo correctly.

### Job titles

Job titles should be capitalized when they come before or after a person’s name. When referring to a job title without referencing a name, don’t capitalize the job title.

<!-- dodont -->

#### Do

- Content Strategist Jane Smith
- Jane Smith, Content Strategist
- Jane Smith is a content strategist.
- The content strategist designed the information architecture.

#### Don’t

- content strategist Jane Smith
- Jane Smith, content strategist
- Jane Smith is a Content Strategist
- The Content Strategist redesigned the information architecture.

<!-- end -->

### Letters following slashes

The first letter following a slash shouldn’t be capitalized.

<!-- dodont -->

#### Do

ZIP/postal code required

#### Don’t

ZIP/Postal code required

<!-- end -->

---

## Headings and subheadings

See the content guidelines for [headings and subheadings](/content/actionable-language#headings-and-subheadings) in the actionable language section.

---

## Lists

### Bulleted

Use a bulleted list when items are related but sequence or priority doesn’t matter.

<!-- dodont -->

#### Do

Use Shopify Payments to:

- Avoid the hassle of setting up a third-party payment gateway
- Track your payout schedule from the Shopify admin
- Minimize lost sales from chargebacks

#### Don’t

Use Shopify payments to

- avoid the hassle of setting up a gateway,
- track pending payout schedule,
- minimize lost sales from chargebacks. And eliminate PCI fees

<!-- end -->

### Numbered

Use a numbered list when item sequence or priority does matter, such as step-by-step instructions.

<!-- dodont -->

#### Do

To set up Shopify Payments:

1.  Go to Settings from Shopify admin
2.  Select Shopify Payments
3.  Select Setup

#### Don’t

To set up Shopify Payments:

1.  Go to Settings from Shopify admin Then select Shopify Payments
2.  Select Setup

<!-- end -->

### Dropdown menus

#### Actions in a menu

Menu lists give users a horizontal set of actions when space is limited. The order of actions is often based on logic such as most popular actions.

Actions in a menu follow a {verb}+{noun} pattern. If there’s enough context, only a verb might be required.

<!-- dodont -->

#### Do

- Rename
- Edit
- HTML
- Duplicate

#### Don’t

- HTML
- editing options
- File name changes
- Duplicate this order so that you can make edits, updates, or changes

<!-- end -->

#### Nouns in a menu

Menu lists give users a horizontal set of nouns when space is limited. The order of nouns is often based on logic such as most recent orders.

Nouns in a menu should be concise but still give the user enough information so they can easily find and accurately select the item they want.

<!-- dodont -->

#### Do

Select filter

- Today
- Yesterday
- This week
- This month

#### Don’t

- Filter visibility
- Filter product type
- Filter product vendor
- Filter tagged with

<!-- end -->

### Capitalization

- List items always start with a capital letter.
- Capitalization and punctuation rules apply to both bulleted and numbered lists.

<!-- dodont -->

#### Do

Company name

- Hidden
- Optional
- Required

#### Don’t

Company name

- hidden
- optional
- required

<!-- end -->

### Punctuation

- Introduce bulleted lists with a colon or a heading.
- Don’t use commas at the end of list items (for bulleted or numbered lists).
- If any list item contains two or more sentences, punctuate all list items.
- If all list items are one sentence or fragments, don’t punctuate.
- Never put a comma or semicolon at the end of a bulleted or numbered list item.
  Treat each list item as a self-contained piece of information.

---

## Dates, numbers, and measurements

Dates, numbers, and measurements are often formatted automatically according users’ local preferences, and they may be formatted differently in other languages. You can use [helpers](https://github.com/Shopify/quilt) to ensure they are localized automatically. These guidelines are for manually formatting in American English, which we use as a base before translating to other languages.

### Date

When possible, use the month’s full name. If there are space constraints, use 3-letter abbreviations. Don’t write dates with numerals only.

<!-- dodont -->

#### Do

- Thursday, October 15, 2015
- October 15, 2015
- Oct 15, 2015

#### Don’t

- Thur, October 15
- October 15, ’15
- 10/15/15

<!-- end -->

Don’t use ordinal indicators, which are words representing position or rank in a sequential order (1st, 2nd, 3rd, and so on).

<!-- dodont -->

#### Do

January 23–April 1

#### Don’t

January 23rd–April 1st

<!-- end -->

### Time

For all translations, the time format is automatically localized by the `Intl.DateTimeFormat` JavaScript object. When time must be formatted manually, follow these guidelines:

- Use the 12-hour clock, followed by am or pm.
- Include a space after the last number. For example, “Your package will arrive at 12:35 pm.” Adding the space helps with formatting for English-speaking markets outside of North America, so we use it for North American usage as well.
- Use the browser time of the logged in user.
- To show a time range, use an en dash and include the am/pm after both times, for example, 3:00 pm–4:00 pm.
- If indicating both the date and time, separate them with the word “at” instead of a comma.

#### Time zones

- Include a time zone only if it’s necessary, such as for an event listing.
- Use the time zone’s abbreviation following the am or pm, for example, 4:00 pm NZT.
- If your audience is in a single time zone, then don’t include an S (for Standard) or D (for Daylight). For example, 3:00 pm PT.
- If your audience is in a combination of time zones, then include the S (for Standard) or D (for Daylight) to avoid confusion. For example, 3:00 pm PDT.

<!-- dodont -->

#### Do

Thursday, October 15, 2015 at 2:00 pm EDT

#### Don’t

2015-10-15, CDT 2:00P.M.

<!-- end -->

Use consistent timestamp formats by following these examples:

<!-- dodont -->

#### Do

- Less than 1 min: `Just now`
- 1 min to 60 min: `13 minutes ago`
- Today: `10:30 am`
- Yesterday: `Yesterday at 10:30 am`
- In the last 7 days: `Friday at 10:30 am`
- 7 days to 1 year: `Aug 14 at 10:30 am`
- More than 1 year: `Aug 14, 2016`

#### Don’t

- Less than 1 min: `10:30am`
- 1 min to 60 min: `10:30am`
- Today: `Today, 10:30am`
- Yesterday: `Friday, 10:30am`
- In the last 7 days: `Friday, 10:30am`
- 7 days to 1 year: `10:30am, Oct 15, 2015`
- More than 1 year: `Last year`

<!-- end -->

### Currency

When including currency with a price, the currency comes after the dollar amount. Learn more about [formatting localized currency](/foundations/formatting-localized-currency).

<!-- dodont -->

#### Do

- \$10,000 USD

#### Don’t

- USD\$10,000
- \$10KUSD
- \$10,000USD

<!-- end -->

### Numbers

In general, use numerals. If the number is below 10 and not integral to the sentence, spell it out in full.

<!-- dodont -->

#### Do

- 9
- 100
- 1
- Here are 2 marketing campaigns you can use.
- You have 3 orders to fulfill.
- You no longer need to track shipments in two places.

#### Don’t

- nine
- one hundred
- one
- Here are two marketing campaigns you can use.
- You have three orders to fulfill.

<!-- end -->

Use commas for numbers with four or more digits. Whenever possible, don’t truncate numbers:

<!-- dodont -->

#### Do

- 12,000
- 9,344
- 1,800,887

#### Don’t

- 12 k
- 9344
- 1.8 m

<!-- end -->

Use hyphens when writing phone numbers. Don’t use brackets, spaces, periods, or plus signs:

<!-- dodont -->

#### Do

- 613-555-1234
- 1-514-555-1234
- 33-55-416-123

#### Don’t

- 613.555.1234
- 1-(514)-555-1234
- +33 55 416 123

<!-- end -->

Use an en dash without a space on either side for number ranges:

<!-- dodont -->

#### Do

- 5–10 products
- October 15–31
- 2005–2015
- 25–100 lb
- \$0.00–\$49.99
- 2:00 pm–3:00 pm

#### Don’t

- 5 – 10 products
- October 15 – 31
- 2005 – 2015
- 25 – 100 lb
- \$0.00 – \$49.99
- 2:00 pm – 3:00 pm

<!-- end -->

Use “to” instead of an en dash if a number range is preceded by “from” in a phrase. Use “and” if a range is preceded by “between.”

<!-- dodont -->

#### Do

- You have a delivery scheduled from 10:00 am to 2:00 pm on Monday, July 18.
- Active from August 15 to August 30
- Free shipping for products between \$10.00 and \$40.00

#### Don’t

- You have a delivery scheduled from 10:00 am–2:00 pm on Monday, July 18.
- Active from August 15–August 30
- Free shipping for products between \$10.00–\$40.00

<!-- end -->

For undefined upward ranges, use “and up” or “or more.”

<!-- dodont -->

#### Do

- \$50.00 and up
- 100 or more

#### Don’t

- \$50.00+
- \>100

<!-- end -->

For downward ranges, be specific.

<!-- dodont -->

#### Do

$0.00–$49.99

#### Don’t

\$50.00 or less

<!-- end -->

### Units of measurement

In all cases, include a space between the number and the unit.

<!-- dodont -->

#### Do

- 3.4 lb
- 2 kg
- 1 cm
- 11.875 × 3.375 × 13.625 cm

#### Don’t

- 3.4lb
- 2kg
- 1.875 × 3.375 × 13.625cm

<!-- end -->

Never pluralize unit of measurement abbreviations.

<!-- dodont -->

#### Do

- 4 lb
- 11 ml

#### Don’t

- 4 lbs
- 11 mls

<!-- end -->

When listing out multiple measurements in a row, put the unit of measurement at the end instead of after each number (and include a space).

<!-- dodont -->

#### Do

- 11.875 × 3.375 × 13.625 cm

#### Don’t

- 1.875 cm × 3.375 cm × 13.625 cm

<!-- end -->

For pricing by measurement, don’t add a space before or after a slash.

<!-- dodont -->

#### Do

- \$100/m
- \$5/100 g

#### Don’t

- \$100/ m
- \$5/ 100g

<!-- end -->

For units of measurement, use decimals instead of fractions:

<!-- dodont -->

#### Do

- 2.375 lb
- 11.875 × 3.375 × 13.625 cm

#### Don’t

- 2-3/8 lb
- 11-7/8 × 3-3/8 × 13-5/8 cm

<!-- end -->

#### Unit of measurement abbreviations

This table shows the standard abbreviations for commonly-used units of measurement.

Use the imperial system for the United States, Liberia, and Myanmar, and use the metric system for all other countries.

| Measurement          | System    | Unit            | Abbreviation |
| -------------------- | --------- | --------------- | ------------ |
| **Area**             | Metric    | square meters   | m²           |
|                      | Imperial  | square feet     | sq ft        |
| **Distance**         | Metric    | kilometers      | km           |
|                      | Imperial  | miles           | mi           |
| **Image resolution** | Universal | pixels          | px           |
|                      | Universal | megapixels      | MP           |
|                      | Universal | pixels per inch | ppi          |
|                      | Universal | dots per inch   | dpi          |
| **Length**           | Metric    | centimeters     | cm           |
|                      | Metric    | meters          | m            |
|                      | Imperial  | inches          | in           |
|                      | Imperial  | feet            | ft           |
|                      | Imperial  | yards           | yd           |
| **Storage size**     | Universal | kilobytes       | KB           |
|                      | Universal | gigabytes       | GB           |
|                      | Universal | terabytes       | TB           |
| **Volume**           | Metric    | milliliters     | ml           |
|                      | Metric    | liters          | L            |
|                      | Imperial  | fluid ounces    | fl oz        |
|                      | Imperial  | gallons         | gal          |
| **Weight**           | Metric    | grams           | g            |
|                      | Metric    | kilograms       | kg           |
|                      | Imperial  | ounces          | oz           |
|                      | Imperial  | pounds          | lb           |

---

## Addresses and places

### Address

Lay out address forms in the following format:

```
First name             Last name
Address
Apartment, suite, etc. (optional)
City
Country            Province           Postal code
```

Please note, “optional” in `Apartment, suite, etc. (optional)` means that the field is optional for customers to complete, but we should always include it in the form.

<!-- dodont -->

#### Do

- Use locale-specific alternatives for province and postal code, for example, the US uses State and ZIP code

#### Don’t

- Add extra fields
- Change the placeholder text

<!-- end -->

### Country, province, and state names

Use a nation’s proper name when referring to it as a noun.

<!-- dodont -->

#### Do

Your store must be located in the United States.

#### Don’t

Your store must be located in the US.

<!-- end -->

When using a country as an adjective (such as when referring to currency), use the abbreviated form without punctuation.

<!-- dodont -->

#### Do

Pinterest requires your store to use US currency.

#### Don’t

U.S. currency

<!-- end -->

Things to watch out for:

- Don’t use colloquial forms of a nation or state name, for example, America instead of the United States
- Search online to see whether nations commonly use “the” before their name, for example, the Philippines or the Falkland Islands

---

## Punctuation

### Ampersands

Don’t use ampersands (&). They attract attention to the least important part of the sentence. Spell out the word “and.”

<!-- dodont -->

#### Do

Zones and rates

#### Don’t

Zones & rates

<!-- end -->

### Apostrophes

Use apostrophes to represent omitted letters or numbers:

- Omitted numbers (’40s)
- Omitted letters (don’t, can’t, won’t)
- Verb contractions (it’s, you’re, we’re)

Use apostrophes to form possessives:

- Singular nouns: add _’s_, even if they end in _s_ (merchant’s, bus’s)
- Plural nouns that don’t end in s: add _’s_ (women’s, men’s)
- Plural nouns that end in s: add an apostrophe (boxes’, customers’)

Don’t use apostrophes to form possessive pronouns such as hers or his.

<!-- dodont -->

#### Do

- Merchant’s store
- Women’s clothing
- Customers’ credit cards

#### Don’t

- Merchants store
- Womens clothing
- Customers credit cards

<!-- end -->

Always use apostrophes, not vertical (straight) quotes.

<!-- dodont -->

#### Do

- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">’</span> <kbd>option</kbd> + <kbd>shift</kbd> + <kbd>]</kbd>

#### Don’t

- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">'</span>

<!-- end -->

### Colons

Avoid using colons in sentences. If you need to use one, don’t capitalize the first word after the colon unless it’s a proper noun.

<!-- dodont -->

#### Do

Your store accepts payments with GoCoin and Shopify Payments.

#### Don’t

Your store accepts payments with: GoCoin and Shopify Payments. Merchants store, womens clothing, customers credit cards

<!-- end -->

Don’t use colons to introduce radio buttons or checkboxes.

<!-- dodont -->

#### Do

If the customer abandons their checkout, send them an email reminder to complete their order

#### Don’t

If the customer abandons their checkout, send them an email reminder to complete their order:

<!-- end -->

Introduce bulleted lists with a colon.

<!-- dodont -->

#### Do

Correct the following payment information to continue:

- The credit card verification value (CVV) doesn’t match the credit card
- The billing address street doesn’t match the street for the credit card
- The billing address ZIP or postal code doesn’t match the credit card address

#### Don’t

Correct the following payment information to continue.

- The credit card verification value (CVV) doesn’t match the credit card
- The billing address street doesn’t match the street for the credit card
- The billing address ZIP or postal code doesn’t match the credit card address

<!-- end -->

### Commas

Use the oxford comma (also known as the serial comma) in sentences. There should be a comma after every list of 3 or more items (unless you’re using a bulleted or numbered list).

<!-- dodont -->

#### Do

Kit is an app that handles your online advertising, email marketing, and social media.

#### Don’t

Kit is an app that handles your online advertising, email marketing and social media.

<!-- end -->

Don’t use commas to separate bulleted or numbered list items.

<!-- dodont -->

#### Do

- The credit card verification value (CVV) doesn’t match the credit card
- The billing address street doesn’t match the street for the credit card
- The billing address ZIP or postal code doesn’t match the credit card address

#### Don’t

- The credit card verification value (CVV) doesn’t match the credit card,
- The billing address street doesn’t match the street for the credit card,
- The billing address ZIP or postal code doesn’t match the credit card address.

<!-- end -->

### Ellipses

The ellipses (…) can be used in place of a missing piece of text (most commonly to show the deletion of words from a direct quotation). Avoid using ellipses in text.

Use ellipses for:

- Truncation in the center of a title bar

Don’t use ellipses for:

- Placeholder copy
- Trailing off a sentence

<!-- dodont -->

#### Do

Search files

#### Don’t

Start typing to search for files…

<!-- end -->

Always use the ellipsis character, not three periods.

<!-- dodont -->

#### Do

<code style="font-size: 5rem; line-height: 0; background-color: transparent">…</code> <kbd>option</kbd> + <kbd>;</kbd>

#### Don’t

<code style="font-size: 5rem; line-height: 0; background-color: transparent">...</code>

<!-- end -->

#### Truncation

Consider constraints of the space in the interface when deciding to use truncation. Think about what part of the string merchants needs most. It’s usually the beginning or end, which means you might have to truncate the middle of the string.

#### Ellipses button component

A button with an ellipsis icon (not the same as text) is used to expand more actions. It’s typically used in cards, or for horizontal sets of actions when space is limited.

### En-dashes and em-dashes

Use an en dash with no spaces in between (–) for a fixed range of numbers

<!-- dodont -->

#### Do

2006–2013

#### Don’t

2006 – 2013

<!-- end -->

Use an em dash only if you can’t make your message clearer by splitting it into two sentences. Use an em dash without a space on either side (—).

<!-- dodont -->

#### Do

Choose your theme’s colors, typography, and pictures—all in one place.

#### Don’t

Choose your theme’s design—colors, typography, and pictures—all in one place.

<!-- end -->

Depending on the font or appearance, you may want to include a hair space on either side of the en or em dash. HTML entity code for hair space is `&hairsp;` or `&#8202;`.

Tip: On Mac the keyboard shortcuts are option - for en dash and shift option - for em dash.

### Exclamation marks

Avoid exclamation marks—only use them for really really exciting things. If you absolutely have to, limit yourself to one exclamation mark per page.

<!-- dodont -->

#### Do

You’ve launched your first online store!

#### Don’t

You’ve updated your product title!

<!-- end -->

### Hyphens

Use hyphens to:

- Form compound modifiers: two words that combine to modify or describe the noun that follows

<!-- dodont -->

#### Do

- Start your free, no-risk, 14-day trial.
- This is a high-risk order.
- This order is high risk.
- Add weight-based shipping rates.
- Add rates based on the weight of an order.

#### Don’t

- Start your free, no risk, 14 day trial.
- This is a high risk order.
- This order is high-risk.
- Add weight based shipping rates.

<!-- end -->

- Join prefixes and suffixes only if there are two vowels beside each other. Never use hyphens in the words ecommerce and email.

<!-- dodont -->

#### Do

- Re-order
- Resend

#### Don’t

- Reorder
- Reenable
- Re-send

<!-- end -->

### Periods

Periods often end up in places they shouldn’t, and are omitted at strange times. In general, don’t use periods in interface copy unless it’s a full sentence description.

When to use periods:

<!-- dodont -->

#### Do

- Complete sentences
- Body text, descriptions, and subtitles
- Help text under text boxes (form fields)
- Timeline events

#### Don’t

- Sentence fragments
- Top-level headings and titles
- Buttons
- Notifications
- Toast messages
- Placeholder copy
- Navigation menu items
- Hover/tooltip text
- Footer help box text
- Radio button and checkbox text

<!-- end -->

<!-- dodont -->

#### Do

- Description example: Add this product to a collection so it’s easy to find in your store.
- Placeholder example: Search products
- Timeline example: \$50.41 USD was authorized.
- Footer help box example: Learn more about [products](https://help.shopify.com/manual/products)

#### Don’t

- Button example: Add product.
- Placeholder example: Search…
- Heading example: I’m Kit, your virtual employee.
- Notification example: 6 orders have payments that need to be captured.

<!-- end -->

#### Periods for bulleted, numbered, and lists of links

<!-- dodont -->

#### Do

- Use when a list item has two or more full sentences, then also add periods to the whole list
- Use for the description or helper text below a bulleted or numbered list item

#### Don’t

- Don’t use periods when a list has only single sentences or fragments
- Don’t use periods for lists of links

<!-- end -->

### Question marks

Avoid question marks wherever possible. Reword into affirmative statements wherever you can, but there are exceptions:

It’s okay to use question marks if you don’t know the result of the question:

- “Did you forget your password?”
- “Do you need to add a shipping rate?”

Don’t use question marks if:

- It’s the only option available: “Reset password”
- It’s an on/off option: “Show quantity box”

<!-- dodont -->

#### Do

- Forgot?

#### Don’t

- Reset password?

<!-- end -->

### Quotation marks

Use quotation marks to:

- Define words (“growth-hacking”)
- Quote text

When it’s helpful to the merchant, use quotation marks to indicate input that the merchant has provided, such as a product title or file name. Use this indication only when the input appears in running text.

<!-- dodont -->

#### Do

- Are you sure you want to delete “cat shirt”?
- “Nike Air Max 90.png” failed to upload

#### Don’t

- Are you sure you want to delete **cat shirt**?
- Nike Air Max 90.png failed to upload

<!-- end -->

In general, place commas and periods inside quotation marks. When working with literal strings like typed commands or merchant inputs, place punctuation outside the quotation marks.

<!-- dodont -->

#### Do

- “I see this all the time,” said Mary.
- Avoid general words like “all,” “every,” or “most.”
- To remove this item, type “DELETE”.

#### Don’t

- “I don’t understand why”, said Mitch.
- We call it a “store”, not a “shop”.
- There was an error with the file “cat_shirt.png.”

<!-- end -->

Always use smart (curly) quotes, not vertical (straight) quotes.

<!-- dodont -->

#### Do

- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">‘</span>
  <kbd>option</kbd> + <kbd>]</kbd>
- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">’</span>
  <kbd>option</kbd> + <kbd>shift</kbd> + <kbd>]</kbd>
- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">“</span>
  <kbd>option</kbd> + <kbd>[</kbd>
- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">”</span>
  <kbd>option</kbd> + <kbd>shift</kbd> + <kbd>[</kbd>

#### Don’t

- <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">"</span> or <span style="font-size: 5rem; line-height: 0; vertical-align: bottom">'</span>

<!-- end -->

### Semicolons

Avoid semicolons if possible. If you really need them, use semicolons to:

- Connect two closely related ideas, as long as they are both independent clauses (full sentences that could stand on their own).
- Replace a comma or the word “and” between two closely related ideas.

<!-- dodont -->

#### Do

My friends made me banana pancakes on my birthday; I’ve never been happier.

#### Don’t

The unicorn was hungry; the grass was brown.

<!-- end -->

---

## Spelling and formatting

### American spelling

Use American spelling for all external-facing Shopify content. When in doubt, check the [Merriam-Webster dictionary](https://www.merriam-webster.com/) for the preferred spelling of specific terms.

<!-- dodont -->

#### Do

- Color
- Center
- Canceled

#### Don’t

- Colour
- Centre
- Cancelled

<!-- end -->

Tip: it’s easy to miss Canadian spelling. Switch your laptop language settings to American English and turn spell check on. It will highlight any Canadianisms you might have missed.

### Bold

When in doubt, don’t bold.

Use bold sparingly and only where strong emphasis is required. Don’t use bold to create a heading or emphasize:

- Proper nouns
- Merchant input
- Checkbox titles

<!-- dodont -->

#### Do

After your first sale, PayPal will email you at **merchant&#64;email.com** with instructions.

#### Don’t

Are you sure you want to delete **Sunset T-shirt**?

<!-- end -->

---

## You, we, and other personal pronouns

### Addressing merchants

Always refer to merchants as “you.” Don’t speak for merchants with phrases that use “I” or “my.”

<!-- dodont -->

#### Do

Change your email address in your Profile.

#### Don’t

Change your email address in My Profile.

<!-- end -->

In some cases (such as getting merchant consent or granting permissions) you should refer to merchants as “I.”

<!-- dodont -->

#### Do

<p><label><input type="checkbox"> I agree to the terms and conditions</label></p>

#### Don’t

<p><label><input type="checkbox"> You agree the terms and conditions</label></p>
 <!-- end -->

### Referring to Shopify

Always refer to Shopify as “we,” but avoid inserting Shopify into the content as much as possible (except when a human is taking action, such as reviewing a request).

<!-- dodont -->

#### Do

Pinterest Buyable Pins will be available in the coming weeks.

#### Don’t

We’re making Pinterest Buyable Pins available in the coming weeks.

<!-- end -->
